FatPtr

Struct FatPtr 

pub struct FatPtr { /* private fields */ }
A fat pointer to noatun materialized view storage.

Contains a start and a count.

Note, in contrast to regular rust fat pointers, the second field really must be a count, and can not be a vtable.

Implementations

Source

impl FatPtr

pub fn from_idx_count(start: usize, count: usize) -> FatPtr

Start index, and size in bytes

pub fn from_thin_size(thin: ThinPtr, size_bytes: usize) -> FatPtr

Gives a fatptr to the size_bytes bytes starting at thin,