pub struct FatPtr { /* private fields */ }Expand description
A fat pointer to noatun materialized view storage.
Contains a start and a count.
Note, in contrast to regular rust fat pointers, the second field really must be a count, and can not be a vtable.
Implementations